==> ajaxplorer-4.2.3.tbz: www/ajaxplorer/plugins/action.scheduler/i18n/en.php <==
<?php
/*
 * Copyright 2007-2011 Charles du Jeu <contact (at) cdujeu.me>
 * This file is part of AjaXplorer.
 *
 * AjaXplorer is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * AjaXplorer is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with AjaXplorer.  If not, see <http://www.gnu.org/licenses/>.
 *
 * The latest code can be found at <http://www.ajaxplorer.info/>.
 */
$mess = array(
    // will be replaced by the application title
    "1" => "Action",
    "1d" => "Action to be performed by this task",
    "2" => "Schedule",
    "2d" => "Crontab like expression under the following format : minutes hours days dayWeeks monthes. You can use wildcards, steps and ranges.",
    "3" => "Next Execution",
    "4" => "Repository ID",
    "4s" => "Repository",
    "4d" => "Id of the target repository",
    "5" => "Parameters",
    "5d" => "Replicable action parameters",
    "6" => "Param Name",
    "6d" => "Action specific parameter name",
    "7" => "Param Value",
    "7d" => "Action specific parameter value",
    "8" => "New task",
    "9" => "Schedule a task to be executed on a regular basis",
    "10" => "Edit task",
    "11" => "Edit scheduled task parameters",
    "12" => "Label",
    "12d"=> "Human readable label for this task",
    "13" => "Status",
    "14" => "Last Execution",
    "15"=> "Run all tasks",
    "15d" => "Trigger selected task now",
    "16" => "Run tasks",
    "16d" => "Trigger scheduler and run scheduled tasks",
    "17" => "User(s)",
    "17d" => "Enter a comma separated list of users, or wildcard * to recurse the task on all users.",
    "18"  => "Scheduler",
    "18d" => "Cron-like scheduler actions",
    "19" => "Delete Task",
    "19d" => "Unschedule and remove the selected task",
    "20" => "Cron Expression",
    "20d" => "Generate Crontab expression",
    "21" => "Add the following line to your CRONTAB, replacing your password real value, and the scheduling you want (here configured to run every five minutes).",
);

==> ajaxplorer-5.0.1.tbz: www/ajaxplorer/plugins/action.scheduler/i18n/en.php <==
<?php
/*
 * Copyright 2007-2011 Charles du Jeu <contact (at) cdujeu.me>
 * This file is part of AjaXplorer.
 *
 * AjaXplorer is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * AjaXplorer is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with AjaXplorer.  If not, see <http://www.gnu.org/licenses/>.
 *
 * The latest code can be found at <http://www.ajaxplorer.info/>.
 */
$mess = array(
    // will be replaced by the application title
    "1" => "Action",
    "1d" => "Action to be performed by this task",
    "2" => "Schedule",
    "2d" => "Crontab like expression under the following format : minutes hours days dayWeeks monthes. You can use wildcards, steps and ranges.",
    "3" => "Next Execution",
    "4" => "Repository ID",
    "4s" => "Repository",
    "4d" => "Id of the target workspace",
    "5" => "Parameters",
    "5d" => "Replicable action parameters",
    "6" => "Param Name",
    "6d" => "Action specific parameter name",
    "7" => "Param Value",
    "7d" => "Action specific parameter value",
    "8" => "New task",
    "9" => "Schedule a task to be executed on a regular basis",
    "10" => "Edit task",
    "11" => "Edit scheduled task parameters",
    "12" => "Label",
    "12d"=> "Human readable label for this task",
    "13" => "Status",
    "14" => "Last Execution",
    "15"=> "Run all tasks",
    "15d" => "Trigger selected task now",
    "16" => "Run task",
    "16d" => "Trigger scheduler and run scheduled tasks",
    "17" => "User(s)",
    "17d" => "Enter a comma separated list of users, or wildcard * to recurse the task on all users.",
    "18"  => "Scheduler",
    "18d" => "Cron-like scheduler actions",
    "19" => "Delete Task",
    "19d" => "Unschedule and remove the selected task",
    "20" => "Cron Expression",
    "20d" => "Generate Crontab expression",
    "21" => "Add the following line to your CRONTAB, replacing your password real value, and the scheduling you want (here configured to run every five minutes).",
    "22" => "Generic scheduler to perform tasks on a regular basis. Requires CLI activation and a CRONTAB or similar system.",
);
